HTMLSuiteResult (Selenium RC Server (Coreless) 1.0.1 API)
Date: 2009-06-09

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV CLASS NEXT CLASS | FRAMES NO FRAMES
SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD

## org.openqa.selenium.server.htmlrunner
Class HTMLSuiteResult

    java.lang.Object
      org.openqa.selenium.server.htmlrunner.HTMLSuiteResult

    public class HTMLSuiteResult

extends java.lang.Object

Constructor Summary
`HTMLSuiteResult(java.lang.String originalSuite)`

Method Summary
`java.lang.String` | `getHref(int i)`
`java.util.List<java.lang.String>` | `getHrefs()`
`java.lang.String` | `getUpdatedSuite()`

Methods inherited from class java.lang.Object
`clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait`

Constructor Detail

### HTMLSuiteResult

    public HTMLSuiteResult(java.lang.String originalSuite)

Method Detail

### getHrefs

    public java.util.List<java.lang.String> getHrefs()

### getHref

    public java.lang.String getHref(int i)

### getUpdatedSuite

    public java.lang.String getUpdatedSuite()

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV CLASS NEXT CLASS | FRAMES NO FRAMES
SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD

Copyright © 2009. All Rights Reserved.